//
// MoonFeature.cpp
// A moonFeature on the moon.
//
//    Copyright 2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

#include "MoonFeature.h"

// Subclasses we know about: we'll call their file-init routines.
#include "Crater.h"

#include <math.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

// Static variables:
int MoonFeature::sMoonRadius = 1;
int MoonFeature::sCurIndex = 0;
MoonFeature** MoonFeature::sMoonFeatureList = 0;
int MoonFeature::sNumFeatures = 0;

MoonFeature::MoonFeature() : mName(0)
{
}

MoonFeature::MoonFeature(char* name, char* desc, int size,
               int longitude, int latitude)
{
    Init(name, desc, size, longitude, latitude);
}

void
MoonFeature::Init(char* name, char* desc, int size,
             int longitude, int latitude)
{
    mName = strdup(name);
    if (desc)
        mDesc = strdup(desc);
    else
        mDesc = 0;
    mSize = size;
    mLongitude = longitude;
    mLatitude = latitude;
}

MoonFeature::~MoonFeature()
{
    if (mName) delete[] mName;
    if (mDesc) delete[] mDesc;
}

char* MoonFeature::GetName()     { return mName; }
char* MoonFeature::GetDesc()     { return mDesc; }
int MoonFeature::GetLongitude()  { return mLongitude; }
int MoonFeature::GetLatitude()   { return mLatitude; }
int MoonFeature::GetSize()       { return mSize; }
int MoonFeature::GetSizeX()      { return mSize; }
int MoonFeature::GetSizeY()      { return mSize; }

// Find the distance from a point to the moonFeature's center.
// If the point is inside the moonFeature, we also set isInside.
double MoonFeature::Distance(double longitude, double latitude, int* isInside)
{
    double dLat = latitude - mLatitude;
    double dLong = longitude - mLongitude;
    // Distance in km of the point from this feature (moon radius = 1738):
    double thisdist = sqrt(dLat*dLat + dLong*dLong) * 1738;
    if (isInside)
        *isInside = (thisdist < GetSizeX()/2 && thisdist < GetSizeY()/2);
#if 0
    printf("%10s (%4d) @ (%4dE, %4dN): click(%4dE, %4dN): dist=%-4d:  %d\n",
           mName, mSize, mLongitude, mLatitude, (int)longitude, (int)latitude,
           (int)thisdist, *isInside);
#endif
    return thisdist;
}

// Routines for looping over all known moonFeatures:
void
MoonFeature::InitMoonFeatures(int moonRadius)
{
    sMoonRadius = moonRadius;

    // Delete the old moonFeature list:
    if (sMoonFeatureList)
        DeleteFeatures();
    sMoonFeatureList = new (MoonFeature*)[2000];

    sNumFeatures = 0;

    Crater::InitCraters();

    printf("%d features loaded\n", sNumFeatures);
}

void
MoonFeature::DeleteFeatures()
{
    // XXX loop and delete all known features here
    printf("ToDo: delete all known features\n");
}

void MoonFeature::InitLoop()
{
    sCurIndex = -1;
}

MoonFeature* MoonFeature::NextFeature()
{
    if (++sCurIndex >= sNumFeatures)
        return 0;
    return sMoonFeatureList[sCurIndex];
}

