//
// MoonMainWin
//
//    Copyright 2002 by Akkana Peck.
// You may use or distribute this code under the terms of the GPL.
//

#include "MoonMainWin.h"

#include "MoonCanvas.h"

#include <qapplication.h>
#include <qtoolbar.h>
#include <qaction.h>
#include <qmessagebox.h>

#include <stdio.h>

MoonMainWin::MoonMainWin( QWidget *parent, const char *name )
    : QMainWindow( parent, name )
{
    setupToolbar();
    mCanvas = new MoonCanvas( this, "skyCanvas" );
    setCentralWidget(mCanvas);
}

void MoonMainWin::setupToolbar()
{
    QToolBar* toolbar = new QToolBar(this, "qmoon");
    toolbar->setHorizontalStretchable(TRUE);

    QAction *a;

    a = new QAction("Mirror",
                    QIconSet(QPixmap("/opt/Qtopia/share/qmoon/mirror.png")),
                    QString::null, 0, this, 0);
    connect(a, SIGNAL(activated()), SLOT(mirror()));
    a->addTo(toolbar);

    // I don't like any of the standard zoom icons, so provide one:
    a = new QAction("Zoom",
                    QIconSet(QPixmap("/opt/Qtopia/share/qmoon/magnify.png")),
                    QString::null, 0, this, 0);
    connect(a, SIGNAL(activated()), SLOT(zoom()));
    a->addTo(toolbar);

    a = new QAction("About", 
                    QIconSet(QPixmap("/opt/Qtopia/share/qmoon/about.png")),
                    QString::null, 0, this, 0);
    connect(a, SIGNAL(activated()), SLOT(aboutDialog()));
    a->addTo(toolbar);

    a = new QAction("Quit", 
                    QIconSet(QPixmap("/opt/Qtopia/share/qmoon/close.png")),
                    QString::null, 0, this, 0);
    connect(a, SIGNAL(activated()), SLOT(quit()));
    a->addTo(toolbar);
}

MoonMainWin::~MoonMainWin()
{
}

void MoonMainWin::quit()
{
    qApp->quit();
}

void MoonMainWin::mirror()
{
    mCanvas->ToggleMirrored();
}

void MoonMainWin::zoom()
{
    printf("zoom\n");
}

void MoonMainWin::aboutDialog()
{
    QMessageBox::information(this, "QMoon",
                             "About QMoon:\n"
                             "Author: Akkana Peck\n"
                             "http://www.shallowsky.com",
                             QMessageBox::Ok);
}
